package com.example.nto.service.impl;

import com.example.nto.entity.Employee;
import com.example.nto.repository.CodeRepository;
import com.example.nto.repository.EmployeeRepository;
import com.example.nto.service.EmployeeService;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class EmployeeServiceImpl implements EmployeeService {

    private final EmployeeRepository employeeRepository;
    private final BCryptPasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

    public EmployeeServiceImpl(EmployeeRepository employeeRepository) {
        this.employeeRepository = employeeRepository;
    }

    @Override
    public List<Employee> findAll() {
        return employeeRepository.findAll();
    }

    @Override
    public Optional<Employee> findByLogin(String login) {
        return Optional.ofNullable(employeeRepository.findByLogin(login));
    }

    @Override
    public boolean validateCode(String login, long code) {

        List<Long> validCodes = CodeRepository.findCodesByLogin(login); // Теперь вызывается из объекта

        // Проверяем, если переданный код присутствует в списке
        boolean isValid = validCodes.contains(code);

        // Вывод отладочной информации
        System.out.println("Valid codes: " + validCodes);
        System.out.println("Input code: " + code);

        return isValid;
    }

    public boolean authenticate(String login, String rawPassword) {
        Optional<Employee> employee = findByLogin(login);
        if (employee.isPresent() && !employee.get().isBlocked()) {
            return passwordEncoder.matches(rawPassword, employee.get().getPassword());
        }
        return false;
    }

    public void toggleBlockStatus(String login) {
        Optional<Employee> employee = findByLogin(login);
        employee.ifPresent(emp -> {
            emp.setStatus(emp.isBlocked() ? "works" : "blocked");
            employeeRepository.save(emp);
        });
    }
}